@@ -33,6 +33,7 @@ def base64Decode(s) -> str:
 
 
 def bytes_decode(b: bytes, default='utf-8') -> str:
+    """bytes自动解码,可以使用默认值，默认值失败就会使用cchardet尝试解码"""
     import cchardet
     try:
         res = b.decode(default)
@@ -261,10 +262,10 @@ class CryptoModel:
 
     def aes_decode(self, data: bytes):
         obj = AES.new(self.key, self.mode, self.iv)
-        return obj.decrypt(data).rstrip(b"\x01").\
-            rstrip(b"\x02").rstrip(b"\x03").rstrip(b"\x04").rstrip(b"\x05").\
-            rstrip(b"\x06").rstrip(b"\x07").rstrip(b"\x08").rstrip(b"\x09").\
-            rstrip(b"\x0a").rstrip(b"\x0b").rstrip(b"\x0c").rstrip(b"\x0d").\
+        return obj.decrypt(data).rstrip(b"\x01"). \
+            rstrip(b"\x02").rstrip(b"\x03").rstrip(b"\x04").rstrip(b"\x05"). \
+            rstrip(b"\x06").rstrip(b"\x07").rstrip(b"\x08").rstrip(b"\x09"). \
+            rstrip(b"\x0a").rstrip(b"\x0b").rstrip(b"\x0c").rstrip(b"\x0d"). \
             rstrip(b"\x0e").rstrip(b"\x0f").rstrip(b"\x10")
 
     def encrypt(self, data):
@@ -300,15 +301,3 @@ class DESModel:
 
     def decrypt(self, data, **kwargs):
         return self.des.decrypt(binascii.a2b_hex(data), **kwargs)
-
-
-if __name__ == '__main__':
-    key = 'cb05362287a2404b'
-    iv = 'a03f3b8977a72276'
-    from base64 import b64decode, b64encode
-    # b = b64decode('Z6v9HtLIECjzMNLwwywkdg==')
-    a = CryptoModel(key=key, iv=iv)
-    b = b64encode(a.aes_encode('{"web": {}}'))
-    print(b)
-    print(a.aes_decode(b64decode(b.decode())))
-
