@@ -29,6 +29,13 @@ class AsyncConsumer(object):
         URL used to connect to RabbitMQ.
 
         :param str amqp_url: The AMQP url to connect with
+        :param str queue: 消息队列名称
+        :param str routing_key: routing_key
+        :param str exchange: exchanges名
+        :param str exchange_type: exchanges类型 - 'direct' 'fanout' 'headers' 'topic'
+        :param asyncio.new_event_loop loop: 在子线程中需要实例化一个新的event_loop
+        :param bool durable: 持久
+        :param func callback: 接收到数据后的callback函数,传参是basic_deliver, properties, body
 
         """
         self.should_reconnect = False
@@ -321,7 +328,10 @@ class AsyncConsumer(object):
         logger.info('Received message # %s from %s: %s',
                     basic_deliver.delivery_tag, properties.app_id, body)
         if self.callback:
-            self.callback(basic_deliver, properties, body)
+            try:
+                self.callback(basic_deliver, properties, body)
+            except Exception:
+                pass
         self.acknowledge_message(basic_deliver.delivery_tag)
 
     def acknowledge_message(self, delivery_tag):
@@ -458,7 +468,7 @@ class Publisher:
     def __enter__(self):
         return self
 
-    def __exit__(self, **kwargs):
+    def __exit__(self, exc_type, exc_val, exc_tb):
         if not self._closed:
             self.close()
 
@@ -496,15 +506,19 @@ class Publisher:
             **kwargs)
 
 # if __name__ == "__main__":
-#     LOG_FORMAT = ('%(levelname) -10s %(asctime)s %(name) -30s %(funcName) '
-#                   '-35s %(lineno) -5d: %(message)s')
-#     logging.basicConfig(level=logging.INFO, format=LOG_FORMAT)
-#     amqp_url = 'amqp://guest:guest@106.54.140.36:5672/%2F'
-#     consumer = ReconnectingAsyncConsumer(amqp_url, queue='TEST01', routing_key='example.text', exchange='message',
-#                                          exchange_type=ExchangeType.topic, loop=asyncio.new_event_loop(), durable=False)
+#     with rabbitmq_obj.Publisher(host='localhost', port=5672) as publisher:
+#         publisher.publish(exchange='message',
+#                           routing_key='example.text',
+#                           body=b'{"test":["publish test"]}')
 #
-#     from threading import Thread
-#
-#     Thread(target=consumer.run).start()
-#     while True:
-#         time.sleep(10000)
+#     consumer = rabbitmq_obj.ReconnectingAsyncConsumer(
+#         amqp_url='amqp://guest:guest@localhost:5672/%2F',
+#         queue='TEST01',
+#         routing_key='example.text',
+#         exchange='message',
+#         exchange_type='topic',
+#         loop=None,
+#         durable=False,
+#         callback=callback
+#     )
+#     consumer.run()
