@@ -104,8 +104,10 @@ def post_json_data(url, data, session=None, check_whos_guo=False):
 
 
 def post_body_json_data(url, data, session=None, check_whos_guo=False):
-    """以json形式发送数据,但是这是漏扫后台可以接收的数据格式"""
-    res = safe_requests(url, session=session, method='POST', data=str(data).replace('\'', '"').encode('utf-8'),
+    """以json形式发送数据,数据会放在body中,这是漏扫后台可以接收的数据格式"""
+    import json
+    res = safe_requests(url, session=session, method='POST',
+                        data=json.dumps(data, ensure_ascii=False).encode('utf-8'),
                         headers={'Content-Type': 'application/json'})
     if isinstance(res, Response):
         if res.status_code == 200:
